package
Version:
v0.0.0-...-181a21d
Opens a new window with list of versions in this module.
Published: Jun 25, 2024
License: MIT, MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
代理模式
代理模式用于延迟处理操作或者在进行实际操作前后进行其它处理。
代理模式的常见用法有
- 虚代理
- COW代理
- 远程代理
- 保护代理
- Cache 代理
- 防火墙代理
- 同步代理
- 智能指引
等。。。
Documentation
¶
type RealSubject struct{}
type Subject interface {
Do() string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.